==> react-link-basic-2.2.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import cx from 'classnames';
import PropTypes from 'prop-types';
import { Link } from '@s-ui/react-router';
import PolymorphicElement from '@s-ui/react-primitive-polymorphic-element';
import { jsxs as _jsxs } from "react/jsx-runtime";
import { jsx as _jsx } from "react/jsx-runtime";

var renderContent = function renderContent(icon, literal) {
  return icon && literal ? /*#__PURE__*/_jsxs("span", {
    children: [icon, literal]
  }) : literal || icon;
};

export default function LinkBasic(_ref) {
  var _ref$as = _ref.as,
      as = _ref$as === void 0 ? 'a' : _ref$as,
      className = _ref.className,
      disabled = _ref.disabled,
      handleClick = _ref.handleClick,
      icon = _ref.icon,
      literal = _ref.literal,
      rel = _ref.rel,
      target = _ref.target,
      title = _ref.title,
      useReactRouterLinks = _ref.useReactRouterLinks,
      _ref$url = _ref.url,
      url = _ref$url === void 0 ? '#' : _ref$url;
  var BASE_CLASS = 'sui-LinkBasic';
  var linkBasicClassName = cx(BASE_CLASS, className);
  var content = renderContent(icon, literal);
  var isAnchor = as === 'a';
  var commonProps = {
    className: linkBasicClassName,
    rel: rel,
    title: title
  };
  var anchorProps = {
    href: url,
    target: target
  };
  var linkProps = {
    target: target,
    to: url
  };

  var onClick = function onClick() {
    handleClick && handleClick();

    if (!isAnchor) {
      window.location.href = url;
    }
  };

  if (disabled) {
    return /*#__PURE__*/_jsx("span", _extends({
      onClick: handleClick
    }, commonProps, {
      children: content
    }));
  }

  if (useReactRouterLinks) {
    return /*#__PURE__*/_jsx(Link, _extends({
      onClick: handleClick
    }, commonProps, linkProps, {
      children: content
    }));
  }

  return /*#__PURE__*/_jsx(PolymorphicElement, _extends({
    as: as,
    onClick: onClick
  }, commonProps, isAnchor ? anchorProps : {}, {
    children: content
  }));
}
LinkBasic.displayName = 'LinkBasic';

==> react-link-basic-2.3.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import cx from 'classnames';
import PropTypes from 'prop-types';
import { Link } from '@s-ui/react-router';
import PolymorphicElement from '@s-ui/react-primitive-polymorphic-element';
import { jsxs as _jsxs } from "react/jsx-runtime";
import { jsx as _jsx } from "react/jsx-runtime";
var renderContent = function renderContent(icon, literal) {
  return icon && literal ? /*#__PURE__*/_jsxs("span", {
    children: [icon, literal]
  }) : literal || icon;
};
export default function LinkBasic(_ref) {
  var _ref$as = _ref.as,
    as = _ref$as === void 0 ? 'a' : _ref$as,
    className = _ref.className,
    disabled = _ref.disabled,
    handleClick = _ref.handleClick,
    icon = _ref.icon,
    literal = _ref.literal,
    rel = _ref.rel,
    target = _ref.target,
    title = _ref.title,
    useReactRouterLinks = _ref.useReactRouterLinks,
    _ref$url = _ref.url,
    url = _ref$url === void 0 ? '#' : _ref$url;
  var BASE_CLASS = 'sui-LinkBasic';
  var linkBasicClassName = cx(BASE_CLASS, className);
  var content = renderContent(icon, literal);
  var isAnchor = as === 'a';
  var commonProps = {
    className: linkBasicClassName,
    rel: rel,
    title: title
  };
  var anchorProps = {
    href: url,
    target: target
  };
  var linkProps = {
    target: target,
    to: url
  };
  var onClick = function onClick(event) {
    handleClick && handleClick(event);
    if (!isAnchor) {
      window.location.href = url;
    }
  };
  if (disabled) {
    return /*#__PURE__*/_jsx("span", _extends({
      onClick: handleClick
    }, commonProps, {
      children: content
    }));
  }
  if (useReactRouterLinks) {
    return /*#__PURE__*/_jsx(Link, _extends({
      onClick: handleClick
    }, commonProps, linkProps, {
      children: content
    }));
  }
  return /*#__PURE__*/_jsx(PolymorphicElement, _extends({
    as: as,
    onClick: onClick
  }, commonProps, isAnchor ? anchorProps : {}, {
    children: content
  }));
}
LinkBasic.displayName = 'LinkBasic';
